==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/event/impl/GenerateSMEventStatementSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.event.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.event.E_GENSet;
import io.ciera.tool.sql.ooaofooa.event.GenerateEventStatementSet;
import io.ciera.tool.sql.ooaofooa.event.GenerateSMEventStatement;
import io.ciera.tool.sql.ooaofooa.event.GenerateSMEventStatementSet;
import io.ciera.tool.sql.ooaofooa.event.GenerateToClassSet;
import io.ciera.tool.sql.ooaofooa.event.GenerateToCreatorSet;
import io.ciera.tool.sql.ooaofooa.event.impl.E_GENSetImpl;
import io.ciera.tool.sql.ooaofooa.event.impl.GenerateEventStatementSetImpl;
import io.ciera.tool.sql.ooaofooa.event.impl.GenerateToClassSetImpl;
import io.ciera.tool.sql.ooaofooa.event.impl.GenerateToCreatorSetImpl;
import io.ciera.tool.sql.ooaofooa.statemachine.StateMachineEventSet;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.StateMachineEventSetImpl;

import java.util.Arrays;
import java.util.List;


public class GenerateSMEventStatementSetImpl extends InstanceSet<GenerateSMEventStatementSet,GenerateSMEventStatement> implements GenerateSMEventStatementSet {

    // attributes
    @Override
    public void setStatement_ID( UniqueId ref_Statement_ID ) throws XtumlException {
        for ( GenerateSMEventStatement generatesmeventstatement : this ) generatesmeventstatement.setStatement_ID( ref_Statement_ID );
    }
    @Override
    public void setSMevt_ID( UniqueId ref_SMevt_ID ) throws XtumlException {
        for ( GenerateSMEventStatement generatesmeventstatement : this ) generatesmeventstatement.setSMevt_ID( ref_SMevt_ID );
    }


    // selections
    @Override
    public GenerateEventStatementSet R703_is_a_GenerateEventStatement() throws XtumlException {
        GenerateEventStatementSet generateeventstatementset = new GenerateEventStatementSetImpl();
        for ( GenerateSMEventStatement generatesmeventstatement : this ) generateeventstatementset.add( generatesmeventstatement.R703_is_a_GenerateEventStatement() );
        return generateeventstatementset;
    }
    @Override
    public E_GENSet R705_is_a_E_GEN() throws XtumlException {
        E_GENSet e_genset = new E_GENSetImpl();
        for ( GenerateSMEventStatement generatesmeventstatement : this ) e_genset.add( generatesmeventstatement.R705_is_a_E_GEN() );
        return e_genset;
    }
    @Override
    public GenerateToClassSet R705_is_a_GenerateToClass() throws XtumlException {
        GenerateToClassSet generatetoclassset = new GenerateToClassSetImpl();
        for ( GenerateSMEventStatement generatesmeventstatement : this ) generatetoclassset.add( generatesmeventstatement.R705_is_a_GenerateToClass() );
        return generatetoclassset;
    }
    @Override
    public GenerateToCreatorSet R705_is_a_GenerateToCreator() throws XtumlException {
        GenerateToCreatorSet generatetocreatorset = new GenerateToCreatorSetImpl();
        for ( GenerateSMEventStatement generatesmeventstatement : this ) generatetocreatorset.add( generatesmeventstatement.R705_is_a_GenerateToCreator() );
        return generatetocreatorset;
    }
    @Override
    public StateMachineEventSet R707_generates_StateMachineEvent() throws XtumlException {
        StateMachineEventSet statemachineeventset = new StateMachineEventSetImpl();
        for ( GenerateSMEventStatement generatesmeventstatement : this ) statemachineeventset.add( generatesmeventstatement.R707_generates_StateMachineEvent() );
        return statemachineeventset;
    }


    @Override
    public GenerateSMEventStatement nullElement() {
        return GenerateSMEventStatementImpl.EMPTY_GENERATESMEVENTSTATEMENT;
    }

    @Override
    public GenerateSMEventStatementSet emptySet() {
      return new GenerateSMEventStatementSetImpl();
    }

    @Override
    public GenerateSMEventStatementSet value() {
        return this;
    }

    @Override
    public List<GenerateSMEventStatement> elements() {
        return Arrays.asList(toArray(new GenerateSMEventStatement[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/event/impl/GenerateSMEventStatementSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.event.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.event.E_GENSet;
import io.ciera.tool.sql.ooaofooa.event.GenerateEventStatementSet;
import io.ciera.tool.sql.ooaofooa.event.GenerateSMEventStatement;
import io.ciera.tool.sql.ooaofooa.event.GenerateSMEventStatementSet;
import io.ciera.tool.sql.ooaofooa.event.GenerateToClassSet;
import io.ciera.tool.sql.ooaofooa.event.GenerateToCreatorSet;
import io.ciera.tool.sql.ooaofooa.event.impl.E_GENSetImpl;
import io.ciera.tool.sql.ooaofooa.event.impl.GenerateEventStatementSetImpl;
import io.ciera.tool.sql.ooaofooa.event.impl.GenerateToClassSetImpl;
import io.ciera.tool.sql.ooaofooa.event.impl.GenerateToCreatorSetImpl;
import io.ciera.tool.sql.ooaofooa.statemachine.StateMachineEventSet;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.StateMachineEventSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class GenerateSMEventStatementSetImpl extends InstanceSet<GenerateSMEventStatementSet,GenerateSMEventStatement> implements GenerateSMEventStatementSet {

    public GenerateSMEventStatementSetImpl() {
    }

    public GenerateSMEventStatementSetImpl(Comparator<? super GenerateSMEventStatement> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setStatement_ID( UniqueId ref_Statement_ID ) throws XtumlException {
        for ( GenerateSMEventStatement generatesmeventstatement : this ) generatesmeventstatement.setStatement_ID( ref_Statement_ID );
    }
    @Override
    public void setSMevt_ID( UniqueId ref_SMevt_ID ) throws XtumlException {
        for ( GenerateSMEventStatement generatesmeventstatement : this ) generatesmeventstatement.setSMevt_ID( ref_SMevt_ID );
    }


    // selections
    @Override
    public GenerateEventStatementSet R703_is_a_GenerateEventStatement() throws XtumlException {
        GenerateEventStatementSet generateeventstatementset = new GenerateEventStatementSetImpl();
        for ( GenerateSMEventStatement generatesmeventstatement : this ) generateeventstatementset.add( generatesmeventstatement.R703_is_a_GenerateEventStatement() );
        return generateeventstatementset;
    }
    @Override
    public E_GENSet R705_is_a_E_GEN() throws XtumlException {
        E_GENSet e_genset = new E_GENSetImpl();
        for ( GenerateSMEventStatement generatesmeventstatement : this ) e_genset.add( generatesmeventstatement.R705_is_a_E_GEN() );
        return e_genset;
    }
    @Override
    public GenerateToClassSet R705_is_a_GenerateToClass() throws XtumlException {
        GenerateToClassSet generatetoclassset = new GenerateToClassSetImpl();
        for ( GenerateSMEventStatement generatesmeventstatement : this ) generatetoclassset.add( generatesmeventstatement.R705_is_a_GenerateToClass() );
        return generatetoclassset;
    }
    @Override
    public GenerateToCreatorSet R705_is_a_GenerateToCreator() throws XtumlException {
        GenerateToCreatorSet generatetocreatorset = new GenerateToCreatorSetImpl();
        for ( GenerateSMEventStatement generatesmeventstatement : this ) generatetocreatorset.add( generatesmeventstatement.R705_is_a_GenerateToCreator() );
        return generatetocreatorset;
    }
    @Override
    public StateMachineEventSet R707_generates_StateMachineEvent() throws XtumlException {
        StateMachineEventSet statemachineeventset = new StateMachineEventSetImpl();
        for ( GenerateSMEventStatement generatesmeventstatement : this ) statemachineeventset.add( generatesmeventstatement.R707_generates_StateMachineEvent() );
        return statemachineeventset;
    }


    @Override
    public GenerateSMEventStatement nullElement() {
        return GenerateSMEventStatementImpl.EMPTY_GENERATESMEVENTSTATEMENT;
    }

    @Override
    public GenerateSMEventStatementSet emptySet() {
      return new GenerateSMEventStatementSetImpl();
    }

    @Override
    public GenerateSMEventStatementSet emptySet(Comparator<? super GenerateSMEventStatement> comp) {
      return new GenerateSMEventStatementSetImpl(comp);
    }

    @Override
    public GenerateSMEventStatementSet value() {
        return this;
    }

    @Override
    public List<GenerateSMEventStatement> elements() {
        return Arrays.asList(toArray(new GenerateSMEventStatement[0]));
    }

}
